#ifndef lint
/*static char yysccsid[] = "from: @(#)yaccpar	1.9 (Berkeley) 02/21/93";*/
static char yyrcsid[]
#if __GNUC__ == 2
  __attribute__ ((unused))
#endif /* __GNUC__ == 2 */
  = "$OpenBSD: skeleton.c,v 1.19 2002/12/03 21:34:21 mickey Exp $";
#endif
#include <stdlib.h>
#define YYBYACC 1
#define YYMAJOR 1
#define YYMINOR 9
#define YYLEX yylex()
#define YYEMPTY -1
#define yyclearin (yychar=(YYEMPTY))
#define yyerrok (yyerrflag=0)
#define YYRECOVERING() (yyerrflag!=0)
#define YYPREFIX "yy"
#line 45 "../../fsinfo/fsi_gram.y"
#ifdef HAVE_CONFIG_H
# include <config.h>
#endif /* HAVE_CONFIG_H */
#include <am_defs.h>
#include <fsi_data.h>
#include <fsinfo.h>

/* AIX requires this to be the first thing in the file. */
#ifndef __GNUC__
# if HAVE_ALLOCA_H
#  include <alloca.h>
# else /* not HAVE_ALLOCA_H */
#  ifdef _AIX
/*
 * This pragma directive is indented so that pre-ANSI C compilers will
 * ignore it, rather than choke on it.
 */
 #pragma alloca
#  else /* not _AIX */
#   ifndef alloca
/* predefined by HP cc +Olibcalls */
voidp alloca();
#   endif /* not alloca */
#  endif /* not _AIX */
# endif /* not HAVE_ALLOCA_H */
#endif /* not __GNUC__ */

extern qelem *list_of_hosts, *list_of_automounts;
#line 75 "../../fsinfo/fsi_gram.y"
typedef union {
	auto_tree *a;
	disk_fs *d;
	ether_if *e;
	host *h;
	qelem *q;
	char *s;
	fsi_mount *m;
	fsmount *f;
} YYSTYPE;
#line 60 "fsi_gram.c"
#define tARCH 257
#define tAS 258
#define tAUTOMOUNT 259
#define tCLUSTER 260
#define tCONFIG 261
#define tDUMPSET 262
#define tEQ 263
#define tNFSEQ 264
#define tEXPORTFS 265
#define tFREQ 266
#define tFROM 267
#define tFS 268
#define tFSTYPE 269
#define tHWADDR 270
#define tINADDR 271
#define tHOST 272
#define tLOCALHOST 273
#define tLOG 274
#define tMOUNT 275
#define tNETMASK 276
#define tNETIF 277
#define tVOLNAME 278
#define tOPTS 279
#define tOS 280
#define tPASSNO 281
#define tDIRECT 282
#define tSEL 283
#define tSTR 284
#define YYERRCODE 256
#if defined(__cplusplus) || defined(__STDC__)
const short yylhs[] =
#else
short yylhs[] =
#endif
	{                                        -1,
    0,    0,    0,    7,    7,    8,    8,    9,    9,    9,
    9,    9,    9,    9,    3,    3,    3,    3,    1,    1,
   14,   14,   10,   10,    5,    5,    6,    6,    6,    6,
    6,    6,    6,    6,    6,    2,    2,    2,    2,    2,
   12,   12,    4,    4,    4,    4,    4,   11,   11,   13,
   13,   13,   13,   13,   13,   13,
};
#if defined(__cplusplus) || defined(__STDC__)
const short yylen[] =
#else
short yylen[] =
#endif
	{                                         2,
    0,    2,    2,    4,    5,    1,    4,    0,    6,    3,
    4,    4,    4,    4,    0,    4,    4,    4,    3,    2,
    0,    2,    0,    2,    5,    3,    0,    4,    4,    4,
    4,    3,    4,    4,    4,    0,    5,    5,    4,    6,
    0,    6,    0,    3,    3,    3,    4,    0,    4,    0,
    2,    3,    3,    3,    3,    4,
};
#if defined(__cplusplus) || defined(__STDC__)
const short yydefred[] =
#else
short yydefred[] =
#endif
	{                                      1,
    0,    0,    0,    0,    3,    2,    0,   20,    0,   36,
    6,    8,   23,   23,   22,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,   24,    0,
    0,    0,    0,    0,    0,    0,   10,    0,    0,    7,
    0,    0,    0,   39,    0,   36,    0,   14,   11,   13,
   15,   12,   26,   27,   50,   38,    0,   37,    0,    0,
    0,   40,    0,    0,    0,    9,    0,    0,    0,    0,
    0,   41,    0,    0,   25,    0,    0,    0,    0,    0,
   51,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,   52,   53,   54,   55,   18,   16,   17,
   35,   33,   31,   28,   34,    0,   29,   30,   56,   43,
    0,    0,    0,    0,    0,    0,    0,   44,   45,   46,
   42,   47,
};
#if defined(__cplusplus) || defined(__STDC__)
const short yydgoto[] =
#else
short yydgoto[] =
#endif
	{                                       1,
    5,   16,   59,  111,   29,   60,    6,   13,   17,   18,
   30,   90,   61,   10,
};
#if defined(__cplusplus) || defined(__STDC__)
const short yysindex[] =
#else
short yysindex[] =
#endif
	{                                      0,
 -239, -253, -240, -118,    0,    0, -118,    0, -262,    0,
    0,    0,    0,    0,    0, -258, -104, -238, -238, -236,
  -33,  -32,  -30, -252, -248,  -17, -237, -243,    0, -230,
 -230, -235,  -61, -234, -233, -232,    0,  -77, -231,    0,
  -71,  -75, -229,    0, -228,    0, -227,    0,    0,    0,
    0,    0,    0,    0,    0,    0, -119,    0,  -91, -107,
 -244,    0,   -3,   -2,   -1,    0,    4,    6,   10,   11,
   12,    0,   13,   14,    0,   15, -223, -221, -220, -216,
    0, -215, -214, -207, -206, -205, -204, -203, -202, -201,
 -200, -199, -198,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  -36,    0,    0,    0,    0,
 -241,   27, -195, -194, -193, -115, -192,    0,    0,    0,
    0,    0,};
#if defined(__cplusplus) || defined(__STDC__)
const short yyrindex[] =
#else
short yyrindex[] =
#endif
	{                                      0,
    0,    0,    1,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    7,    0,    2,    2,  -57,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    8,
    9,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    3,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  -85,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 -114,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,};
#if defined(__cplusplus) || defined(__STDC__)
const short yygindex[] =
#else
short yygindex[] =
#endif
	{                                      0,
    0,   47,    0,    0,    0,    0,    0,   87,    0,   81,
   77,  -14,    0,   78,
};
#define YYTABLESIZE 285
#if defined(__cplusplus) || defined(__STDC__)
const short yytable[] =
#else
short yytable[] =
#endif
	{                                      47,
   21,   48,   49,   21,   12,   62,   19,    4,    5,  121,
   41,   76,   41,   77,  112,    8,    2,   75,    7,    3,
   27,   15,   78,  113,   79,   20,   32,   34,   35,   28,
   36,   37,    4,   66,   80,   38,  114,   81,    9,   32,
   42,  115,    9,   39,   43,   51,   40,   54,   44,   48,
   49,   50,   52,   53,   55,   56,   58,   82,   83,   84,
   94,   46,   95,   96,   85,   21,   86,   97,   98,   99,
   87,   88,   89,   91,   92,   93,  100,  101,  102,  103,
  104,  105,  106,  107,  108,  109,  110,  117,  118,  119,
  120,  122,   57,   14,   19,   31,  116,   33,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,   67,    0,
    0,   21,   22,    0,   68,   23,   24,    0,   69,    0,
    0,   70,    0,    0,   20,   11,   71,   72,  106,   41,
   32,   73,   25,   74,    0,   26,   32,    0,   63,   64,
   32,    0,    0,   32,   65,    0,    0,    0,   32,   32,
    0,    0,    0,   32,    0,   32,    0,    0,    0,    0,
    0,    0,   45,    0,    0,    0,   21,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,   48,    0,   21,
   48,   49,   19,    4,    5,   19,    4,    5,    0,    0,
    0,    0,   21,   48,   49,    0,   48,   49,   19,    4,
    5,    0,    0,    0,   21,
};
#if defined(__cplusplus) || defined(__STDC__)
const short yycheck[] =
#else
short yycheck[] =
#endif
	{                                      61,
    0,    0,    0,   61,  123,  125,    0,    0,    0,  125,
  125,  256,  256,  258,  256,  256,  256,  125,  272,  259,
  125,  284,  267,  265,  269,  284,  263,   61,   61,  268,
   61,  284,  272,  125,  279,  284,  278,  282,  279,  125,
  284,  283,  279,   61,  275,  123,  284,  123,  284,  284,
  284,  284,  284,  125,  284,  284,  284,   61,   61,   61,
  284,  123,  284,  284,   61,  123,   61,  284,  284,  284,
   61,   61,   61,   61,   61,   61,  284,  284,  284,  284,
  284,  284,  284,  284,  284,  284,  123,   61,  284,  284,
  284,  284,   46,    7,   14,   19,  111,   20,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  256,   -1,
   -1,  256,  257,   -1,  262,  260,  261,   -1,  266,   -1,
   -1,  269,   -1,   -1,  284,  284,  274,  275,  284,  284,
  256,  279,  277,  281,   -1,  280,  262,   -1,  270,  271,
  266,   -1,   -1,  269,  276,   -1,   -1,   -1,  274,  275,
   -1,   -1,   -1,  279,   -1,  281,   -1,   -1,   -1,   -1,
   -1,   -1,  264,   -1,   -1,   -1,  264,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  256,   -1,  259,
  259,  259,  256,  256,  256,  259,  259,  259,   -1,   -1,
   -1,   -1,  272,  272,  272,   -1,  275,  275,  272,  272,
  272,   -1,   -1,   -1,  284,
};
#define YYFINAL 1
#ifndef YYDEBUG
#define YYDEBUG 0
#endif
#define YYMAXTOKEN 284
#if YYDEBUG
#if defined(__cplusplus) || defined(__STDC__)
const char * const yyname[] =
#else
char *yyname[] =
#endif
	{
"end-of-file",0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,"'='",0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,"'{'",0,"'}'",0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,"tARCH","tAS",
"tAUTOMOUNT","tCLUSTER","tCONFIG","tDUMPSET","tEQ","tNFSEQ","tEXPORTFS","tFREQ",
"tFROM","tFS","tFSTYPE","tHWADDR","tINADDR","tHOST","tLOCALHOST","tLOG",
"tMOUNT","tNETMASK","tNETIF","tVOLNAME","tOPTS","tOS","tPASSNO","tDIRECT",
"tSEL","tSTR",
};
#if defined(__cplusplus) || defined(__STDC__)
const char * const yyrule[] =
#else
char *yyrule[] =
#endif
	{"$accept : list_of_hosts",
"list_of_hosts :",
"list_of_hosts : list_of_hosts host",
"list_of_hosts : list_of_hosts automount",
"host : tHOST host_attr list_of_filesystems list_of_mounts",
"host : error tHOST host_attr list_of_filesystems list_of_mounts",
"host_attr : tSTR",
"host_attr : '{' host_attr_list '}' tSTR",
"host_attr_list :",
"host_attr_list : host_attr_list tNETIF tSTR '{' ether_attr '}'",
"host_attr_list : host_attr_list tCONFIG tSTR",
"host_attr_list : host_attr_list tARCH '=' tSTR",
"host_attr_list : host_attr_list tOS '=' tSTR",
"host_attr_list : host_attr_list tCLUSTER '=' tSTR",
"host_attr_list : host_attr_list error '=' tSTR",
"ether_attr :",
"ether_attr : ether_attr tINADDR '=' tSTR",
"ether_attr : ether_attr tNETMASK '=' tSTR",
"ether_attr : ether_attr tHWADDR '=' tSTR",
"automount : tAUTOMOUNT opt_auto_opts automount_tree",
"automount : tAUTOMOUNT error",
"opt_auto_opts :",
"opt_auto_opts : tOPTS tSTR",
"list_of_filesystems :",
"list_of_filesystems : list_of_filesystems filesystem",
"filesystem : tFS tSTR '{' fs_info_list '}'",
"filesystem : tFS error '}'",
"fs_info_list :",
"fs_info_list : fs_info_list tFSTYPE '=' tSTR",
"fs_info_list : fs_info_list tOPTS '=' tSTR",
"fs_info_list : fs_info_list tPASSNO '=' tSTR",
"fs_info_list : fs_info_list tFREQ '=' tSTR",
"fs_info_list : fs_info_list tMOUNT dir_tree",
"fs_info_list : fs_info_list tDUMPSET '=' tSTR",
"fs_info_list : fs_info_list tLOG '=' tSTR",
"fs_info_list : fs_info_list error '=' tSTR",
"automount_tree :",
"automount_tree : automount_tree tSTR opt_auto_opts '=' tSTR",
"automount_tree : automount_tree tSTR opt_auto_opts tNFSEQ tSTR",
"automount_tree : automount_tree tSTR tEQ tSTR",
"automount_tree : automount_tree tSTR opt_auto_opts '{' automount_tree '}'",
"dir_tree :",
"dir_tree : dir_tree tSTR '{' dir_tree_info dir_tree '}'",
"dir_tree_info :",
"dir_tree_info : dir_tree_info tEXPORTFS tSTR",
"dir_tree_info : dir_tree_info tVOLNAME tSTR",
"dir_tree_info : dir_tree_info tSEL tSTR",
"dir_tree_info : dir_tree_info error '=' tSTR",
"list_of_mounts :",
"list_of_mounts : list_of_mounts tMOUNT tSTR localinfo_list",
"localinfo_list :",
"localinfo_list : localinfo_list tDIRECT",
"localinfo_list : localinfo_list tAS tSTR",
"localinfo_list : localinfo_list tFROM tSTR",
"localinfo_list : localinfo_list tFSTYPE tSTR",
"localinfo_list : localinfo_list tOPTS tSTR",
"localinfo_list : localinfo_list error '=' tSTR",
};
#endif
#ifdef YYSTACKSIZE
#undef YYMAXDEPTH
#define YYMAXDEPTH YYSTACKSIZE
#else
#ifdef YYMAXDEPTH
#define YYSTACKSIZE YYMAXDEPTH
#else
#define YYSTACKSIZE 10000
#define YYMAXDEPTH 10000
#endif
#endif
#define YYINITSTACKSIZE 200
int yydebug;
int yynerrs;
int yyerrflag;
int yychar;
short *yyssp;
YYSTYPE *yyvsp;
YYSTYPE yyval;
YYSTYPE yylval;
short *yyss;
short *yysslim;
YYSTYPE *yyvs;
int yystacksize;
/* allocate initial stack or double stack size, up to YYMAXDEPTH */
#if defined(__cplusplus) || defined(__STDC__)
static int yygrowstack(void)
#else
static int yygrowstack()
#endif
{
    int newsize, i;
    short *newss;
    YYSTYPE *newvs;

    if ((newsize = yystacksize) == 0)
        newsize = YYINITSTACKSIZE;
    else if (newsize >= YYMAXDEPTH)
        return -1;
    else if ((newsize *= 2) > YYMAXDEPTH)
        newsize = YYMAXDEPTH;
    i = yyssp - yyss;
    newss = yyss ? (short *)realloc(yyss, newsize * sizeof *newss) :
      (short *)malloc(newsize * sizeof *newss);
    if (newss == NULL)
        goto bail;
    yyss = newss;
    yyssp = newss + i;
    newvs = yyvs ? (YYSTYPE *)realloc(yyvs, newsize * sizeof *newvs) :
      (YYSTYPE *)malloc(newsize * sizeof *newvs);
    if (newvs == NULL)
        goto bail;
    yyvs = newvs;
    yyvsp = newvs + i;
    yystacksize = newsize;
    yysslim = yyss + newsize - 1;
    return 0;
bail:
    if (yyss)
            free(yyss);
    if (yyvs)
            free(yyvs);
    yyss = yyssp = NULL;
    yyvs = yyvsp = NULL;
    yystacksize = 0;
    return -1;
}

#define YYABORT goto yyabort
#define YYREJECT goto yyabort
#define YYACCEPT goto yyaccept
#define YYERROR goto yyerrlab
int
#if defined(__cplusplus) || defined(__STDC__)
yyparse(void)
#else
yyparse()
#endif
{
    int yym, yyn, yystate;
#if YYDEBUG
#if defined(__cplusplus) || defined(__STDC__)
    const char *yys;
#else /* !(defined(__cplusplus) || defined(__STDC__)) */
    char *yys;
#endif /* !(defined(__cplusplus) || defined(__STDC__)) */

    if ((yys = getenv("YYDEBUG")))
    {
        yyn = *yys;
        if (yyn >= '0' && yyn <= '9')
            yydebug = yyn - '0';
    }
#endif /* YYDEBUG */

    yynerrs = 0;
    yyerrflag = 0;
    yychar = (-1);

    if (yyss == NULL && yygrowstack()) goto yyoverflow;
    yyssp = yyss;
    yyvsp = yyvs;
    *yyssp = yystate = 0;

yyloop:
    if ((yyn = yydefred[yystate]) != 0) goto yyreduce;
    if (yychar < 0)
    {
        if ((yychar = yylex()) < 0) yychar = 0;
#if YYDEBUG
        if (yydebug)
        {
            yys = 0;
            if (yychar <= YYMAXTOKEN) yys = yyname[yychar];
            if (!yys) yys = "illegal-symbol";
            printf("%sdebug: state %d, reading %d (%s)\n",
                    YYPREFIX, yystate, yychar, yys);
        }
#endif
    }
    if ((yyn = yysindex[yystate]) && (yyn += yychar) >= 0 &&
            yyn <= YYTABLESIZE && yycheck[yyn] == yychar)
    {
#if YYDEBUG
        if (yydebug)
            printf("%sdebug: state %d, shifting to state %d\n",
                    YYPREFIX, yystate, yytable[yyn]);
#endif
        if (yyssp >= yysslim && yygrowstack())
        {
            goto yyoverflow;
        }
        *++yyssp = yystate = yytable[yyn];
        *++yyvsp = yylval;
        yychar = (-1);
        if (yyerrflag > 0)  --yyerrflag;
        goto yyloop;
    }
    if ((yyn = yyrindex[yystate]) && (yyn += yychar) >= 0 &&
            yyn <= YYTABLESIZE && yycheck[yyn] == yychar)
    {
        yyn = yytable[yyn];
        goto yyreduce;
    }
    if (yyerrflag) goto yyinrecovery;
#if defined(lint) || defined(__GNUC__)
    goto yynewerror;
#endif
yynewerror:
    yyerror("syntax error");
#if defined(lint) || defined(__GNUC__)
    goto yyerrlab;
#endif
yyerrlab:
    ++yynerrs;
yyinrecovery:
    if (yyerrflag < 3)
    {
        yyerrflag = 3;
        for (;;)
        {
            if ((yyn = yysindex[*yyssp]) && (yyn += YYERRCODE) >= 0 &&
                    yyn <= YYTABLESIZE && yycheck[yyn] == YYERRCODE)
            {
#if YYDEBUG
                if (yydebug)
                    printf("%sdebug: state %d, error recovery shifting\
 to state %d\n", YYPREFIX, *yyssp, yytable[yyn]);
#endif
                if (yyssp >= yysslim && yygrowstack())
                {
                    goto yyoverflow;
                }
                *++yyssp = yystate = yytable[yyn];
                *++yyvsp = yylval;
                goto yyloop;
            }
            else
            {
#if YYDEBUG
                if (yydebug)
                    printf("%sdebug: error recovery discarding state %d\n",
                            YYPREFIX, *yyssp);
#endif
                if (yyssp <= yyss) goto yyabort;
                --yyssp;
                --yyvsp;
            }
        }
    }
    else
    {
        if (yychar == 0) goto yyabort;
#if YYDEBUG
        if (yydebug)
        {
            yys = 0;
            if (yychar <= YYMAXTOKEN) yys = yyname[yychar];
            if (!yys) yys = "illegal-symbol";
            printf("%sdebug: state %d, error recovery discards token %d (%s)\n",
                    YYPREFIX, yystate, yychar, yys);
        }
#endif
        yychar = (-1);
        goto yyloop;
    }
yyreduce:
#if YYDEBUG
    if (yydebug)
        printf("%sdebug: state %d, reducing by rule %d (%s)\n",
                YYPREFIX, yystate, yyn, yyrule[yyn]);
#endif
    yym = yylen[yyn];
    yyval = yyvsp[1-yym];
    switch (yyn)
    {
case 1:
#line 131 "../../fsinfo/fsi_gram.y"
{ yyval.q = new_que(); }
break;
case 2:
#line 134 "../../fsinfo/fsi_gram.y"
{ if (yyvsp[0].h) ins_que((qelem *) yyvsp[0].h, list_of_hosts->q_back);
	    yyval.q = yyvsp[-1].q; }
break;
case 3:
#line 138 "../../fsinfo/fsi_gram.y"
{ if (yyvsp[0].a) ins_que((qelem *) yyvsp[0].a, list_of_automounts->q_back);
	    yyval.q = yyvsp[-1].q; }
break;
case 4:
#line 149 "../../fsinfo/fsi_gram.y"
{ yyval.h = yyvsp[-2].h; yyval.h->h_disk_fs = yyvsp[-1].q; yyval.h->h_mount = yyvsp[0].q; }
break;
case 5:
#line 152 "../../fsinfo/fsi_gram.y"
{ yyval.h = yyvsp[-2].h; yyval.h->h_disk_fs = yyvsp[-1].q; yyval.h->h_mount = yyvsp[0].q; }
break;
case 6:
#line 158 "../../fsinfo/fsi_gram.y"
{ yyval.h = new_host(); set_host(yyval.h, HF_HOST, yyvsp[0].s); }
break;
case 7:
#line 161 "../../fsinfo/fsi_gram.y"
{ yyval.h = yyvsp[-2].h; set_host(yyval.h, HF_HOST, yyvsp[0].s); }
break;
case 8:
#line 167 "../../fsinfo/fsi_gram.y"
{ yyval.h = new_host(); }
break;
case 9:
#line 170 "../../fsinfo/fsi_gram.y"
{ if (yyvsp[-1].e) {
		yyvsp[-1].e->e_if = yyvsp[-3].s;
		yyval.h = yyvsp[-5].h; set_host(yyval.h, HF_ETHER, (char *) yyvsp[-1].e); }
	  }
break;
case 10:
#line 176 "../../fsinfo/fsi_gram.y"
{ yyval.h = yyvsp[-2].h; set_host(yyval.h, HF_CONFIG, yyvsp[0].s); }
break;
case 11:
#line 179 "../../fsinfo/fsi_gram.y"
{ yyval.h = yyvsp[-3].h; set_host(yyval.h, HF_ARCH, yyvsp[0].s); }
break;
case 12:
#line 182 "../../fsinfo/fsi_gram.y"
{ yyval.h = yyvsp[-3].h; set_host(yyval.h, HF_OS, yyvsp[0].s); }
break;
case 13:
#line 185 "../../fsinfo/fsi_gram.y"
{ yyval.h = yyvsp[-3].h; set_host(yyval.h, HF_CLUSTER, yyvsp[0].s); }
break;
case 14:
#line 188 "../../fsinfo/fsi_gram.y"
{ yyerror("unknown host attribute"); }
break;
case 15:
#line 193 "../../fsinfo/fsi_gram.y"
{ yyval.e = new_ether_if(); }
break;
case 16:
#line 196 "../../fsinfo/fsi_gram.y"
{ yyval.e = yyvsp[-3].e; set_ether_if(yyval.e, EF_INADDR, yyvsp[0].s); }
break;
case 17:
#line 198 "../../fsinfo/fsi_gram.y"
{ yyval.e = yyvsp[-3].e; set_ether_if(yyval.e, EF_NETMASK, yyvsp[0].s); }
break;
case 18:
#line 200 "../../fsinfo/fsi_gram.y"
{ yyval.e = yyvsp[-3].e; set_ether_if(yyval.e, EF_HWADDR, yyvsp[0].s); }
break;
case 19:
#line 210 "../../fsinfo/fsi_gram.y"
{ if (yyvsp[0].q) {
		yyval.a = new_auto_tree(yyvsp[-1].s, yyvsp[0].q);
	    } else {
		yyval.a = 0;
	    }
	  }
break;
case 20:
#line 218 "../../fsinfo/fsi_gram.y"
{ yyval.a = 0; }
break;
case 21:
#line 223 "../../fsinfo/fsi_gram.y"
{ yyval.s = strdup(""); }
break;
case 22:
#line 226 "../../fsinfo/fsi_gram.y"
{ yyval.s = yyvsp[0].s; }
break;
case 23:
#line 231 "../../fsinfo/fsi_gram.y"
{ yyval.q = 0; }
break;
case 24:
#line 234 "../../fsinfo/fsi_gram.y"
{ if (yyvsp[0].d) {
		if (yyvsp[-1].q)
			yyval.q = yyvsp[-1].q;
		else
			yyval.q = new_que();
		ins_que(&yyvsp[0].d->d_q, yyval.q->q_back);
	    } else {
		yyval.q = yyvsp[-1].q;
	    }
	  }
break;
case 25:
#line 253 "../../fsinfo/fsi_gram.y"
{ yyvsp[-1].d->d_dev = yyvsp[-3].s; yyval.d = yyvsp[-1].d; }
break;
case 26:
#line 256 "../../fsinfo/fsi_gram.y"
{ yyval.d = (disk_fs *) 0; }
break;
case 27:
#line 272 "../../fsinfo/fsi_gram.y"
{ yyval.d = new_disk_fs(); }
break;
case 28:
#line 275 "../../fsinfo/fsi_gram.y"
{ yyval.d = yyvsp[-3].d; set_disk_fs(yyval.d, DF_FSTYPE, yyvsp[0].s); }
break;
case 29:
#line 278 "../../fsinfo/fsi_gram.y"
{ yyval.d = yyvsp[-3].d; set_disk_fs(yyval.d, DF_OPTS, yyvsp[0].s); }
break;
case 30:
#line 281 "../../fsinfo/fsi_gram.y"
{ yyval.d = yyvsp[-3].d; set_disk_fs(yyval.d, DF_PASSNO, yyvsp[0].s); }
break;
case 31:
#line 284 "../../fsinfo/fsi_gram.y"
{ yyval.d = yyvsp[-3].d; set_disk_fs(yyval.d, DF_FREQ, yyvsp[0].s); }
break;
case 32:
#line 287 "../../fsinfo/fsi_gram.y"
{ yyval.d = yyvsp[-2].d; set_disk_fs(yyval.d, DF_MOUNT, (char *) yyvsp[0].q); }
break;
case 33:
#line 290 "../../fsinfo/fsi_gram.y"
{ yyval.d = yyvsp[-3].d; set_disk_fs(yyval.d, DF_DUMPSET, yyvsp[0].s); }
break;
case 34:
#line 293 "../../fsinfo/fsi_gram.y"
{ yyval.d = yyvsp[-3].d; set_disk_fs(yyval.d, DF_LOG, yyvsp[0].s); }
break;
case 35:
#line 296 "../../fsinfo/fsi_gram.y"
{ yyerror("unknown filesystem attribute"); }
break;
case 36:
#line 310 "../../fsinfo/fsi_gram.y"
{ yyval.q = 0; }
break;
case 37:
#line 313 "../../fsinfo/fsi_gram.y"
{ automount *a = new_automount(yyvsp[-3].s);
	    a->a_volname = yyvsp[0].s;
	    a->a_opts = yyvsp[-2].s;
	    if (yyvsp[-4].q)
		yyval.q = yyvsp[-4].q;
	    else
		yyval.q = new_que();
	    ins_que(&a->a_q, yyval.q->q_back);
	  }
break;
case 38:
#line 323 "../../fsinfo/fsi_gram.y"
{ automount *a = new_automount(yyvsp[-3].s);
            a->a_hardwiredfs = yyvsp[0].s;
            a->a_opts = yyvsp[-2].s;
            if (yyvsp[-4].q)
                yyval.q = yyvsp[-4].q;
            else
                yyval.q = new_que();
            ins_que(&a->a_q, yyval.q->q_back);
          }
break;
case 39:
#line 334 "../../fsinfo/fsi_gram.y"
{ automount *a = new_automount(yyvsp[-2].s);
	    a->a_symlink = yyvsp[0].s;
	    if (yyvsp[-3].q)
		yyval.q = yyvsp[-3].q;
	    else
		yyval.q = new_que();
	    ins_que(&a->a_q, yyval.q->q_back);
	  }
break;
case 40:
#line 344 "../../fsinfo/fsi_gram.y"
{ automount *a = new_automount(yyvsp[-4].s);
	    a->a_mount = yyvsp[-1].q;
	    a->a_opts = yyvsp[-3].s;
	    if (yyvsp[-5].q)
		yyval.q = yyvsp[-5].q;
	    else
		yyval.q = new_que();
	    ins_que(&a->a_q, yyval.q->q_back);
	  }
break;
case 41:
#line 357 "../../fsinfo/fsi_gram.y"
{ yyval.q = 0; }
break;
case 42:
#line 360 "../../fsinfo/fsi_gram.y"
{ yyvsp[-2].m->m_mount = yyvsp[-1].q;
	    yyvsp[-2].m->m_name = yyvsp[-4].s;
	    if (yyvsp[-4].s[0] != '/' && yyvsp[-4].s[1] && strchr(yyvsp[-4].s+1, '/'))
		yyerror("not allowed '/' in a directory name");
	    if (yyvsp[-5].q)
		yyval.q = yyvsp[-5].q;
	    else
		yyval.q = new_que();
	    ins_que(&yyvsp[-2].m->m_q, yyval.q->q_back);
	  }
break;
case 43:
#line 374 "../../fsinfo/fsi_gram.y"
{ yyval.m = new_mount(); }
break;
case 44:
#line 377 "../../fsinfo/fsi_gram.y"
{ yyval.m = yyvsp[-2].m; set_mount(yyval.m, DM_EXPORTFS, yyvsp[0].s); }
break;
case 45:
#line 380 "../../fsinfo/fsi_gram.y"
{ yyval.m = yyvsp[-2].m; set_mount(yyval.m, DM_VOLNAME, yyvsp[0].s); }
break;
case 46:
#line 383 "../../fsinfo/fsi_gram.y"
{ yyval.m = yyvsp[-2].m; set_mount(yyval.m, DM_SEL, yyvsp[0].s); }
break;
case 47:
#line 386 "../../fsinfo/fsi_gram.y"
{ yyerror("unknown directory attribute"); }
break;
case 48:
#line 396 "../../fsinfo/fsi_gram.y"
{ yyval.q = 0; }
break;
case 49:
#line 399 "../../fsinfo/fsi_gram.y"
{ set_fsmount(yyvsp[0].f, FM_VOLNAME, yyvsp[-1].s);
	    if (yyvsp[-3].q)
		yyval.q = yyvsp[-3].q;
	    else
		yyval.q = new_que();
	    ins_que(&yyvsp[0].f->f_q, yyval.q->q_back);
	    }
break;
case 50:
#line 419 "../../fsinfo/fsi_gram.y"
{ yyval.f = new_fsmount(); }
break;
case 51:
#line 422 "../../fsinfo/fsi_gram.y"
{ yyval.f = yyvsp[-1].f; set_fsmount(yyval.f, FM_DIRECT, ""); }
break;
case 52:
#line 425 "../../fsinfo/fsi_gram.y"
{ yyval.f = yyvsp[-2].f; set_fsmount(yyval.f, FM_LOCALNAME, yyvsp[0].s); }
break;
case 53:
#line 428 "../../fsinfo/fsi_gram.y"
{ yyval.f = yyvsp[-2].f; set_fsmount(yyval.f, FM_FROM, yyvsp[0].s); }
break;
case 54:
#line 431 "../../fsinfo/fsi_gram.y"
{ yyval.f = yyvsp[-2].f; set_fsmount(yyval.f, FM_FSTYPE, yyvsp[0].s); }
break;
case 55:
#line 434 "../../fsinfo/fsi_gram.y"
{ yyval.f = yyvsp[-2].f; set_fsmount(yyval.f, FM_OPTS, yyvsp[0].s); }
break;
case 56:
#line 437 "../../fsinfo/fsi_gram.y"
{ yyerror("unknown mount attribute"); }
break;
#line 806 "fsi_gram.c"
    }
    yyssp -= yym;
    yystate = *yyssp;
    yyvsp -= yym;
    yym = yylhs[yyn];
    if (yystate == 0 && yym == 0)
    {
#if YYDEBUG
        if (yydebug)
            printf("%sdebug: after reduction, shifting from state 0 to\
 state %d\n", YYPREFIX, YYFINAL);
#endif
        yystate = YYFINAL;
        *++yyssp = YYFINAL;
        *++yyvsp = yyval;
        if (yychar < 0)
        {
            if ((yychar = yylex()) < 0) yychar = 0;
#if YYDEBUG
            if (yydebug)
            {
                yys = 0;
                if (yychar <= YYMAXTOKEN) yys = yyname[yychar];
                if (!yys) yys = "illegal-symbol";
                printf("%sdebug: state %d, reading %d (%s)\n",
                        YYPREFIX, YYFINAL, yychar, yys);
            }
#endif
        }
        if (yychar == 0) goto yyaccept;
        goto yyloop;
    }
    if ((yyn = yygindex[yym]) && (yyn += yystate) >= 0 &&
            yyn <= YYTABLESIZE && yycheck[yyn] == yystate)
        yystate = yytable[yyn];
    else
        yystate = yydgoto[yym];
#if YYDEBUG
    if (yydebug)
        printf("%sdebug: after reduction, shifting from state %d \
to state %d\n", YYPREFIX, *yyssp, yystate);
#endif
    if (yyssp >= yysslim && yygrowstack())
    {
        goto yyoverflow;
    }
    *++yyssp = yystate;
    *++yyvsp = yyval;
    goto yyloop;
yyoverflow:
    yyerror("yacc stack overflow");
yyabort:
    return (1);
yyaccept:
    return (0);
}
